@@ -1,7 +1,13 @@
 import json
+from tkinter import E
 import pika
 import pika.exceptions
 import time
+from eon_logger import logging as rabbit_log
+
+cls = rabbit_log.Logs_Manager('rabbit_mq', 'debug')
+_logger = cls.create_logger()
+
 
 class ManageConsumers(): 
     def __init__(self, service_name, handler, config):
@@ -30,10 +36,10 @@ class ManageConsumers():
                                     credentials)
             self._conn = pika.BlockingConnection(parameters)
             self._channel = self._conn.channel()
-            print('connected to Arnoob')
+            _logger.info('connected to RabbitMQ Server')
 
-        except (pika.exceptions.ConnectionBlockedTimeout, pika.exceptions.ConnectionClosed, pika.exceptions.AMQPConnectionError, Exception) as e:
-            print("trying to reconnect", e)
+        except Exception as err:
+            _logger.error(f'Error processing job {err}')
             time.sleep(10)
             self.connect()
             
@@ -45,12 +51,12 @@ class ManageConsumers():
             return
 
         try:
-            # self.handler(str(message))
-            print("publishing at : ", self.successful_job_routing_key)
+            self.handler(str(message))
+            _logger.info("publishing at : ", self.successful_job_routing_key)
             channel.basic_publish(exchange=self.exchange_name, routing_key=self.successful_job_routing_key, body=json.dumps(message))
         except Exception as err:
-            print('Error processing job', err)
-            print(message)
+            _logger.error(f'Error processing job {err}')
+            _logger.info(message)
             message['reason'] = str(err)
             channel.basic_publish(exchange=self.exchange_name, routing_key=self.failed_job_routing_key, body=json.dumps(message))
             
